Index: test/codegen/expect/try_catch.js |
diff --git a/test/codegen/expect/try_catch.js b/test/codegen/expect/try_catch.js |
index 9ad17ef3a632d4cf824bc6822f71f2858da271ae..8a5d5b8c48a6597c9c2c36a9007c9c9f0c35eafd 100644 |
--- a/test/codegen/expect/try_catch.js |
+++ b/test/codegen/expect/try_catch.js |
@@ -1,21 +1,39 @@ |
var try_catch; |
(function(exports) { |
'use strict'; |
- // Function main: () → dynamic |
- function main() { |
+ // Function foo: () → dynamic |
+ function foo() { |
try { |
throw "hi there"; |
- } catch ($e) { |
- if (dart.is($e, core.String)) { |
- let e = $e; |
+ } catch (e$) { |
+ if (dart.is(e$, core.String)) { |
+ let e = e$; |
+ let t = dart.stackTrace(e); |
+ } else { |
+ let e = e$; |
let t = dart.stackTrace(e); |
+ throw e; |
} |
- let e = $e; |
+ } |
+ |
+ } |
+ // Function bar: () → dynamic |
+ function bar() { |
+ try { |
+ throw "hi there"; |
+ } catch (e$) { |
+ let e = e$; |
let t = dart.stackTrace(e); |
- throw e; |
} |
} |
+ // Function main: () → dynamic |
+ function main() { |
+ foo(); |
+ bar(); |
+ } |
// Exports: |
+ exports.foo = foo; |
+ exports.bar = bar; |
exports.main = main; |
})(try_catch || (try_catch = {})); |